.. image:: https://raw.githubusercontent.com/albahnsen/CostSensitiveClassification/master/logo.png

CostSensitiveClassification
===========================

costcla is a Python module for cost-sensitive machine learning (classification)
built on top of `Scikit-Learn <http://scikit-learn.org/stable/>`__, `SciPy <http://www.scipy.org/>`__
and distributed under the 3-Clause BSD license.

In particular, it provides:

1. A set of example-dependent cost-sensitive algorithms
2. Different reald-world example-dependent cost-sensitive datasets.

The project is part of the PhD research of `Alejandro Correa Bahnsen <http://albahnsen.com>`__.

Installation
============

You can install ``costcla`` with ``pip``::

    # pip install costcla
    
Documentation
=============

Documentation is available at 
http://albahnsen.github.com/CostSensitiveClassification

Tutorials are available at
http://albahnsen.com/CostSensitiveClassification/Tutorials.html

Development
=============

Source code is available at https://github.com/albahnsen/CostSensitiveClassification
